@@ -40,11 +40,7 @@ int osip_message_set_route(osip_message_t *sip, const char *hvalue) {
   if (hvalue == NULL || hvalue[0] == '\0')
     return OSIP_SUCCESS;
 
-#ifdef __VXWORKS_OS__
-  i = osip_route_init2(&route);
-#else
   i = osip_route_init(&route);
-#endif
 
   if (i != 0)
     return i;
